pub enum PollError {
ShutDown,
TonicError(Status),
}Expand description
Errors thrown by crate::Worker polling methods
Variants
ShutDown
crate::Worker::shutdown was called, and there are no more tasks to be handled from this poll function. Lang must call crate::Worker::complete_workflow_activation, crate::Worker::complete_activity_task, or crate::Worker::complete_nexus_task for any remaining tasks, and then may exit.
TonicError(Status)
Unhandled error when calling the temporal server. Core will attempt to retry any non-fatal errors, so lang should consider this fatal.