pub enum PollerBehavior {
SimpleMaximum(usize),
Autoscaling {
minimum: usize,
maximum: usize,
initial: usize,
},
}Expand description
Different strategies for task polling
Variants
SimpleMaximum(usize)
Will attempt to poll as long as a slot is available, up to the provided maximum. Cannot be less than two for workflow tasks, or one for other tasks.
Autoscaling
Will automatically scale the number of pollers based on feedback from the server. Still requires a slot to be available before beginning polling.
Implementations