#[non_exhaustive]pub struct ClientTlsOptions {
pub client_cert: Vec<u8>,
pub client_private_key: Vec<u8>,
}Expand description
If using mTLS, both the client cert and private key must be specified, this contains them.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_cert: Vec<u8>The certificate for this client, encoded as PEM
client_private_key: Vec<u8>The private key for this client, encoded as PEM
Implementations
Sourceimpl ClientTlsOptions
impl ClientTlsOptions
Sourcepub fn builder() -> ClientTlsOptionsBuilder
pub fn builder() -> ClientTlsOptionsBuilder
Create an instance of ClientTlsOptions using the builder syntax