#[non_exhaustive]pub struct ResourceBasedSlotsOptions {
pub target_mem_usage: f64,
pub target_cpu_usage: f64,
pub mem_p_gain: f64,
pub mem_i_gain: f64,
pub mem_d_gain: f64,
pub mem_output_threshold: f64,
pub cpu_p_gain: f64,
pub cpu_i_gain: f64,
pub cpu_d_gain: f64,
pub cpu_output_threshold: f64,
}Expand description
Allows for the full customization of the PID options for a resource based tuner
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_mem_usage: f64A value in the range [0.0, 1.0] representing the target memory usage.
target_cpu_usage: f64A value in the range [0.0, 1.0] representing the target CPU usage.
mem_p_gain: f64See pid::Pid::p
mem_i_gain: f64See pid::Pid::i
mem_d_gain: f64See pid::Pid::d
mem_output_threshold: f64If the mem PID controller outputs a value higher than this, we say the mem half of things will allow a slot
cpu_p_gain: f64See pid::Pid::d
cpu_i_gain: f64See pid::Pid::i
cpu_d_gain: f64See pid::Pid::d
cpu_output_threshold: f64If the CPU PID controller outputs a value higher than this, we say the CPU half of things will allow a slot
Implementations
Sourceimpl ResourceBasedSlotsOptions
impl ResourceBasedSlotsOptions
Sourcepub fn builder() -> ResourceBasedSlotsOptionsBuilder
pub fn builder() -> ResourceBasedSlotsOptionsBuilder
Create an instance of ResourceBasedSlotsOptions using the builder syntax