#[non_exhaustive]pub struct TunerHolderOptions {
pub workflow_slot_options: Option<SlotSupplierOptions<WorkflowSlotKind>>,
pub activity_slot_options: Option<SlotSupplierOptions<ActivitySlotKind>>,
pub local_activity_slot_options: Option<SlotSupplierOptions<LocalActivitySlotKind>>,
pub nexus_slot_options: Option<SlotSupplierOptions<NexusSlotKind>>,
pub resource_based_options: Option<ResourceBasedSlotsOptions>,
}Expand description
Can be used to construct a TunerHolder without needing to manually construct each SlotSupplier. Useful for lang bridges to allow more easily passing through user options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_slot_options: Option<SlotSupplierOptions<WorkflowSlotKind>>Options for workflow slots
activity_slot_options: Option<SlotSupplierOptions<ActivitySlotKind>>Options for activity slots
local_activity_slot_options: Option<SlotSupplierOptions<LocalActivitySlotKind>>Options for local activity slots
nexus_slot_options: Option<SlotSupplierOptions<NexusSlotKind>>Options for nexus slots
resource_based_options: Option<ResourceBasedSlotsOptions>Options that will apply to all resource based slot suppliers. Must be set if any slot options are SlotSupplierOptions::ResourceBased
Implementations
Sourceimpl TunerHolderOptions
impl TunerHolderOptions
Sourcepub fn builder() -> TunerHolderOptionsBuilder
pub fn builder() -> TunerHolderOptionsBuilder
Create an instance of TunerHolderOptions using the builder syntax
Sourceimpl TunerHolderOptions
impl TunerHolderOptions
Sourcepub fn build_tuner_holder(self) -> Result<TunerHolder, Error>
pub fn build_tuner_holder(self) -> Result<TunerHolder, Error>
Create a TunerHolder from these options