pub struct WorkflowTaskCompletion {
pub task_token: TaskToken,
pub commands: Vec<Command>,
pub messages: Vec<Message>,
pub sticky_attributes: Option<StickyExecutionAttributes>,
pub query_responses: Vec<QueryResult>,
pub return_new_workflow_task: bool,
pub force_create_new_workflow_task: bool,
pub sdk_metadata: WorkflowTaskCompletedMetadata,
pub metering_metadata: MeteringMetadata,
pub versioning_behavior: VersioningBehavior,
}Expand description
A version of RespondWorkflowTaskCompletedRequest that will finish being filled out by the server client
Fields
task_token: TaskTokenThe task token that would’ve been received from polling for a workflow activation
commands: Vec<Command>A list of new commands to send to the server, such as starting a timer.
messages: Vec<Message>A list of protocol messages to send to the server.
sticky_attributes: Option<StickyExecutionAttributes>If set, indicate that next task should be queued on sticky queue with given attributes.
query_responses: Vec<QueryResult>Responses to queries in the queries field of the workflow task.
return_new_workflow_task: boolIndicate that the task completion should return a new WFT if one is available
force_create_new_workflow_task: boolForce a new WFT to be created after this completion
sdk_metadata: WorkflowTaskCompletedMetadataSDK-specific metadata to send
metering_metadata: MeteringMetadataMetering info
versioning_behavior: VersioningBehaviorVersioning behavior of the workflow, if any.