PollerBehavior

Enum PollerBehavior 

pub enum PollerBehavior {
    SimpleMaximum(usize),
    Autoscaling {
        minimum: usize,
        maximum: usize,
        initial: usize,
    },
}
Different strategies for task polling

Variants



SimpleMaximum(usize)

Will attempt to poll as long as a slot is available, up to the provided maximum. Cannot be less than two for workflow tasks, or one for other tasks.



Autoscaling

Will automatically scale the number of pollers based on feedback from the server. Still requires a slot to be available before beginning polling.

Fields

minimum: usize

At least this many poll calls will always be attempted (assuming slots are available). Cannot be zero.

maximum: usize

At most this many poll calls will ever be open at once. Must be >= minimum.

initial: usize

This many polls will be attempted initially before scaling kicks in. Must be between minimum and maximum.

Implementations

Source

impl PollerBehavior

pub fn is_autoscaling(&self) -> bool

Returns true if the behavior is using autoscaling.

pub fn validate(&self) -> Result<(), String>

Validates the behavior.